TelephonySmsException class
Thrown when the platform side of the plugin fails.
- Implemented types
Constructors
- TelephonySmsException(TelephonySmsErrorCode code, String message)
-
Creates an exception with an explicit
codeandmessage.const
Properties
- code → TelephonySmsErrorCode
-
Why the call failed.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- message → String
-
A human-readable description of the failure.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override