MethodChannelTelephonySMS class
An implementation of TelephonySMSPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- TelephonySMSPlatform
- MethodChannelTelephonySMS
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestPermission(
) → Future< bool> -
Requests the
SEND_SMSpermission, resolving to whether it was granted.override -
sendSMS(
{required String phone, required String message, SmsCompletion completeOn = SmsCompletion.sent, Duration timeout = const Duration(seconds: 30)}) → Future< void> -
Sends
messagetophone, completing whencompleteOnis satisfied or failing aftertimeout.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited