TelephonySMSPlatform class abstract

The interface that platform-specific implementations of telephony_sms must extend.

Implementations should extend this class rather than implement it, so that new members are inherited rather than breaking the build.

Inheritance
  • Object
  • PlatformInterface
  • TelephonySMSPlatform
Implementers

Constructors

TelephonySMSPlatform()
Constructs a TelephonySmsPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermission() Future<bool>
Requests the SEND_SMS permission, resolving to whether it was granted.
sendSMS({required String phone, required String message, SmsCompletion completeOn = SmsCompletion.sent, Duration timeout = const Duration(seconds: 30)}) Future<void>
Sends message to phone, completing when completeOn is satisfied or failing after timeout.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance TelephonySMSPlatform
The default instance of TelephonySMSPlatform to use.
getter/setter pair